@@ -38,8 +38,12 @@ grid->setColumnStretch(2, 20);
 // load current
 
 QFile file("/opt/psx4m/keys");
-     if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
-         return;
+if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
+    QMessageBox msg;
+    msg.setText(tr("Couldn't open previous key config"));
+    msg.exec();
+}
+
 int o=0;
      QTextStream in(&file);
      while ((o<21)) {
