@@ -263,6 +263,8 @@ void MainWindow::save_ch(){
 void MainWindow::fm_skip_ch(){
     QAction *action = qobject_cast<QAction *>(sender());
     frameskiping=action->text().toInt();
+    if (action->text()=="Auto")frameskiping=-1;
+    if (action->text()=="Off")frameskiping=0;
     settings->setValue("frame-skipping",frameskiping);
 }
 void MainWindow::cml_ch(){
